@@ -2,8 +2,8 @@ spDistsN1 <- function(pts, pt, longlat=FALSE) {
 	if (!is.matrix(pts)) stop("pts must be a matrix")
 	if (ncol(pts) != 2) stop("pts must have two columns")
 	if (!is.numeric(pts)) stop("pts must be numeric")
-	if (!is.numeric(pt)) stop("pts must be numeric")
-	if (length(pt) != 2) stop("pts must have length two")
+	if (!is.numeric(pt)) stop("pt must be numeric")
+	if (length(pt) != 2) stop("pt must have length two")
 	x <- as.double(pts[,1])
 	y <- as.double(pts[,2])
 	xx <- as.double(pt[1])
